package betterquesting.api2.client.gui.controls;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import java.util.List;
import java.util.function.Consumer;
import net.minecraft.client.Minecraft;
import net.minecraft.client.audio.PositionedSoundRecord;
import net.minecraft.client.gui.FontRenderer;
import net.minecraft.util.MathHelper;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.input.Mouse;
import org.lwjgl.opengl.GL11;

/* loaded from: betterquesting_api2_client_gui_controls.jar:betterquesting/api2/client/gui/controls/PanelButton.class */
public class PanelButton implements IPanelButton {
    private static final ResourceLocation CLICK_SND = new ResourceLocation("gui.button.press");
    private final IGuiRect transform;
    private String btnText;
    private final int btnID;
    private boolean enabled = true;
    private final IGuiTexture[] texStates = new IGuiTexture[3];
    private IGuiColor[] colStates = {new GuiColorStatic(128, 128, 128, 255), new GuiColorStatic(255, 255, 255, 255), new GuiColorStatic(16777120)};
    private IGuiTexture texIcon = null;
    private IGuiColor colIcon = null;
    private int icoPadding = 0;
    private List<String> tooltip = null;
    private boolean txtShadow = true;
    private int textAlign = 1;
    private boolean isActive = true;
    private boolean pendingRelease = false;
    private Consumer<PanelButton> clickAction = null;

    public PanelButton(IGuiRect rect, int id, String txt) {
        this.transform = rect;
        this.btnText = txt;
        this.btnID = id;
        setTextures(PresetTexture.BTN_NORMAL_0.getTexture(), PresetTexture.BTN_NORMAL_1.getTexture(), PresetTexture.BTN_NORMAL_2.getTexture());
        setTextHighlight(PresetColor.BTN_DISABLED.getColor(), PresetColor.BTN_IDLE.getColor(), PresetColor.BTN_HOVER.getColor());
    }

    public PanelButton setClickAction(Consumer<PanelButton> action) {
        this.clickAction = action;
        return this;
    }

    public PanelButton setTextHighlight(IGuiColor disabled, IGuiColor idle, IGuiColor hover) {
        this.colStates[0] = disabled;
        this.colStates[1] = idle;
        this.colStates[2] = hover;
        return this;
    }

    public PanelButton setTextShadow(boolean enabled) {
        this.txtShadow = enabled;
        return this;
    }

    public PanelButton setTextAlignment(int align) {
        this.textAlign = MathHelper.func_76125_a(align, 0, 2);
        return this;
    }

    public PanelButton setTextures(IGuiTexture disabled, IGuiTexture idle, IGuiTexture hover) {
        this.texStates[0] = disabled;
        this.texStates[1] = idle;
        this.texStates[2] = hover;
        return this;
    }

    public PanelButton setIcon(IGuiTexture icon) {
        return setIcon(icon, 0);
    }

    public PanelButton setIcon(IGuiTexture icon, int padding) {
        return setIcon(icon, null, padding);
    }

    public PanelButton setIcon(IGuiTexture icon, IGuiColor color, int padding) {
        this.texIcon = icon;
        this.colIcon = color;
        this.icoPadding = padding * 2;
        return this;
    }

    public PanelButton setTooltip(List<String> tooltip) {
        this.tooltip = tooltip;
        return this;
    }

    public void setText(String text) {
        this.btnText = text;
    }

    public String getText() {
        return this.btnText;
    }

    @Override // betterquesting.api2.client.gui.controls.IPanelButton
    public int getButtonID() {
        return this.btnID;
    }

    @Override // betterquesting.api2.client.gui.controls.IPanelButton
    public boolean isActive() {
        return this.isActive;
    }

    @Override // betterquesting.api2.client.gui.controls.IPanelButton
    public void setActive(boolean state) {
        this.isActive = state;
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public void setEnabled(boolean state) {
        this.enabled = state;
    }

    public IGuiRect getTransform() {
        return this.transform;
    }

    public void initPanel() {
    }

    public void drawPanel(int mx, int my, float partialTick) {
        int isz;
        IGuiRect bounds = getTransform();
        GL11.glPushMatrix();
        GL11.glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
        int curState = !isActive() ? 0 : bounds.contains(mx, my) ? 2 : 1;
        if (curState == 2 && this.pendingRelease && Mouse.isButtonDown(0)) {
            curState = 0;
        }
        IGuiTexture t = this.texStates[curState];
        if (t != null) {
            t.drawTexture(bounds.getX(), bounds.getY(), bounds.getWidth(), bounds.getHeight(), 0.0f, partialTick);
        }
        if (this.texIcon != null && (isz = Math.min(bounds.getHeight() - this.icoPadding, bounds.getWidth() - this.icoPadding)) > 0) {
            if (this.colIcon != null) {
                this.texIcon.drawTexture((bounds.getX() + (bounds.getWidth() / 2)) - (isz / 2), (bounds.getY() + (bounds.getHeight() / 2)) - (isz / 2), isz, isz, 0.0f, partialTick, this.colIcon);
            } else {
                this.texIcon.drawTexture((bounds.getX() + (bounds.getWidth() / 2)) - (isz / 2), (bounds.getY() + (bounds.getHeight() / 2)) - (isz / 2), isz, isz, 0.0f, partialTick);
            }
        }
        if (this.btnText != null && this.btnText.length() > 0) {
            drawCenteredString(Minecraft.func_71410_x().field_71466_p, this.btnText, bounds.getX(), (bounds.getY() + (bounds.getHeight() / 2)) - 4, bounds.getWidth(), this.colStates[curState].getRGB(), this.txtShadow, this.textAlign);
        }
        GL11.glPopMatrix();
    }

    private static void drawCenteredString(FontRenderer font, String text, int x, int y, int width, int color, boolean shadow, int align) {
        switch (align) {
            case 0:
                font.func_85187_a(text, x + 4, y, color, shadow);
                return;
            case 2:
                font.func_85187_a(text, MathHelper.func_76141_d(((x + width) - (RenderUtils.getStringWidth(text, font) / 2.0f)) - 4.0f), y, color, shadow);
                return;
            default:
                font.func_85187_a(text, MathHelper.func_76141_d((x + Math.floorDiv(width, 2)) - (RenderUtils.getStringWidth(text, font) / 2.0f)), y, color, shadow);
                return;
        }
    }

    public boolean onMouseClick(int mx, int my, int click) {
        boolean contains = getTransform().contains(mx, my);
        this.pendingRelease = isActive() && click == 0 && contains;
        return (click == 0 || click == 1) && contains;
    }

    public boolean onMouseRelease(int mx, int my, int click) {
        if (!this.pendingRelease) {
            return false;
        }
        this.pendingRelease = false;
        IGuiRect bounds = getTransform();
        boolean clicked = isActive() && click == 0 && bounds.contains(mx, my) && !PEventBroadcaster.INSTANCE.postEvent(new PEventButton(this));
        if (clicked) {
            Minecraft.func_71410_x().func_147118_V().func_147682_a(PositionedSoundRecord.func_147674_a(CLICK_SND, 1.0f));
            onButtonClick();
        }
        return clicked;
    }

    public boolean onMouseScroll(int mx, int my, int scroll) {
        return false;
    }

    public boolean onKeyTyped(char c, int keycode) {
        return false;
    }

    public List<String> getTooltip(int mx, int my) {
        if (getTransform().contains(mx, my)) {
            return this.tooltip;
        }
        return null;
    }

    @Override // betterquesting.api2.client.gui.controls.IPanelButton
    public void onButtonClick() {
        if (this.clickAction != null) {
            this.clickAction.accept(this);
        }
    }
}
